==> haskell-monad-loops-0.4.3-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-loops.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-loops
version:              0.4.3
visibility:           public
id:                   monad-loops-0.4.3-1PoLx7GFY2f6JjKzBe0o6E
key:                  monad-loops-0.4.3-1PoLx7GFY2f6JjKzBe0o6E
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/monad-loops
synopsis:             Monadic loops
description:
    Some useful control operators for looping.

    New in 0.4: STM loop operators have been split into a
    new package instead of being conditionally-built.

    New in 0.3.2.0: various functions for traversing lists and
    computing minima/maxima using arbitrary procedures to compare
    or score the elements.

category:             Control
abi:                  7b7f6be831722578b60f7cafdb7a10ea
exposed:              True
exposed-modules:      Control.Monad.Loops
import-dirs:          /usr/lib/ghc-9.2.8/site-local/monad-loops-0.4.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monad-loops-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-loops
hs-libraries:         HSmonad-loops-0.4.3-1PoLx7GFY2f6JjKzBe0o6E
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-monad-loops/html/monad-loops.haddock
haddock-html:         /usr/share/doc/haskell-monad-loops/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-loops-0.4.3-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-loops.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-loops
version:              0.4.3
visibility:           public
id:                   monad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z
key:                  monad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/monad-loops
synopsis:             Monadic loops
description:
    Some useful control operators for looping.

    New in 0.4: STM loop operators have been split into a
    new package instead of being conditionally-built.

    New in 0.3.2.0: various functions for traversing lists and
    computing minima/maxima using arbitrary procedures to compare
    or score the elements.

category:             Control
abi:                  7c9fbcaa74fb9c458b49e57e97fd4e0d
exposed:              True
exposed-modules:      Control.Monad.Loops
import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-loops-0.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-loops-0.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-loops-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-loops
hs-libraries:         HSmonad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-monad-loops/html/monad-loops.haddock
haddock-html:         /usr/share/doc/haskell-monad-loops/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
